#
# spec file for package xdelta3
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           xdelta3
Version:        3.1.0
Release:        5.12
Summary:        A diff utility which works with binary files
License:        Apache-2.0 AND GPL-2.0-only
Group:          Productivity/Archiving/Compression
URL:            http://xdelta.org/
Source0:        https://github.com/jmacd/xdelta-devel/releases/download/v%{version}/xdelta3-%{version}.tar.gz
BuildRequires:  gcc-c++
BuildRequires:  python3
BuildRequires:  xz-devel
# xdelta is being dropped
Provides:       xdelta = %{version}
Obsoletes:      xdelta < %{version}
%if 0%{?opensuse}
# Dependency of tests
BuildRequires:  ncompress
%endif

%description
Xdelta3 is a set of tools designed to compute changes between
binary files.  These changes (delta files) are similar to the output of the
"diff" program, in that they may be used to store and transmit only the
changes between files.  The "delta files" that Xdelta3 manages are
stored in RFC3284 (VCDIFF) format.

%prep
%autosetup

%build
%configure
%ifarch ppc64 s390x
%define do_profiling 0
%endif
%if %{do_profiling}
  %make_build CFLAGS="%{optflags} %{cflags_profile_generate}" CXXFLAGS="%{optflags} %{cflags_profile_generate}"
  ./xdelta3 test
  %make_build clean
  %make_build CFLAGS="%{optflags} %{cflags_profile_feedback}" CXXFLAGS="%{optflags} %{cflags_profile_feedback}"
%else
  %make_build CFLAGS="%{optflags}" CXXFLAGS="%{optflags}"
%endif

%install
%make_install

# Create compat symlinks
ln -sv %{_bindir}/xdelta3 \
  %{buildroot}%{_bindir}/xdelta
ln -sv %{_mandir}/man1/xdelta3.1 \
  %{buildroot}%{_mandir}/man1/xdelta.1

%check
./xdelta3regtest

%files
%license COPYING
%doc README.md
%{_bindir}/xdelta
%{_bindir}/xdelta3
%{_mandir}/man1/xdelta.1%{?ext_man}
%{_mandir}/man1/xdelta3.1%{?ext_man}

%changelog
* Mon Jun 28 2021 Matej Cepl <mcepl@suse.com>
- We don't need python2, works perfectly fine with the standard
  python3.
* Fri Feb 12 2021 Michel Normand <normand@linux.vnet.ibm.com>
- Do not build with profiling for ppc64 & s390x to avoid build failure
  for those big-endian arches; this is a bypass only for bug
  https://bugzilla.opensuse.org/show_bug.cgi?id=1182016
* Fri Jan 29 2021 Martin Pluskal <mpluskal@suse.com>
- Run tests using upstrem test wrapper
- Small packaging updates
* Mon Feb  4 2019 Petr Gajdos <pgajdos@suse.com>
- do not require ancient ncompress for build in SLES
  (externally_compressed_io subtest will not run for ncompress)
  * why: ncompress is not part of SLES
- package also README.md
  * why: contains useful info
* Thu Jun 29 2017 mpluskal@suse.com
- Update licensing information
* Wed Jun 21 2017 mpluskal@suse.com
- Update to version 3.1:
  * Adds support for -B values greater than 2GB, enabled by
  - DXD3_USE_LARGESIZET=1 variable
  * Adds new performance and speed regression test
- Obsolete xdelta
- Install manpage as well
- Use profiling when building
* Tue Feb  9 2016 pgajdos@suse.com
- updated to 3.0.11
  * bug-fix release addressing a performance bug and several
    crashes in the decoder
* Fri Jan  1 2016 mpluskal@suse.com
- Don't strip binary
* Sat Sep 19 2015 mpluskal@suse.com
- Update to 3.0.10
  * see https://github.com/jmacd/xdelta-devel/releases for details
- Update download url
- Cleanup spec file with spec-cleaner
- Drop xdelta3-regtest.patch as it is no longer necessary
* Tue Jun 24 2014 pgajdos@suse.com
- fix 32-bit build (testsuite helper)
- added patches:
  * xdelta3-regtest.patch
* Mon Jun 23 2014 pgajdos@suse.com
- updated to 3.0.8:
  * bugfixes, see http://xdelta.org/ for details
* Mon Nov  7 2011 pgajdos@suse.com
- "GPLv2" to "GPL-2.0"
* Mon Oct 31 2011 pgajdos@suse.com
- make test
* Tue Oct  4 2011 pgajdos@suse.com
- Updated to 3.0.0
* Tue Jul 13 2010 mook.moz+rpm.buildservice@gmail.com
- Initial package (xdelta 3.0y)
